import{I as c}from"./ItemsListing-ck1RuJ2A.js";import{ay as u,J as r,ax as i,a3 as p,aP as a,bb as m,a4 as f,aI as v,aA as _}from"./index-It2prjj_.js";import"./Container-DVHdDHGo.js";import"./index-kQIztB-E.js";import"./Toolbar-B4cAstji.js";import"./VToolbar-d3S4vzQ8.js";import"./Button-BMZw2h0c.js";import"./ListItem-CZP-Ank1.js";import"./userPreferences-D5hXrNCo.js";import"./VCheckboxBtn-CeJlTA3J.js";import"./VSelectionControl-B-NDe8ob.js";import"./MediaItemThumb-7RT8HKcH.js";import"./PanelviewItemCompact-D2-QnU9K.js";import"./VInfiniteScroll-C95z5bNw.js";import"./VVirtualScroll-OOfSuXB2.js";import"./VAlert-C9ByNQuJ.js";const x=u({name:"Podcasts",__name:"LibraryPodcasts",setup(y){const o=r(!1),e=r(i.libraryPodcastsCount),d=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","timestamp_modified","timestamp_modified_desc","last_played","last_played_desc","play_count","play_count_desc"],l=async function(t){return o.value=!1,n(t),await a.getLibraryPodcasts(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy,t.provider&&t.provider.length>0?t.provider:void 0)},n=async function(t){if(!t.favoritesOnly&&!t.provider){e.value=i.libraryPodcastsCount;return}if(t.provider&&t.provider.length>0){e.value=void 0;return}e.value=await a.getLibraryPodcastsCount(t.favoritesOnly||!1)};return p(()=>{const t=a.subscribe(m.MEDIA_ITEM_ADDED,s=>{s.object_id?.startsWith("library://podcast")&&(o.value=!0)});f(t)}),(t,s)=>(_(),v(c,{itemtype:"podcasts",path:"librarypodcasts","show-duration":!1,"show-provider":!0,"show-favorites-only-filter":!0,"load-paged-data":l,"show-library":!0,"sort-keys":d,"update-available":o.value,title:t.$t("podcasts"),"allow-key-hooks":!0,"show-search-button":!0,icon:"mdi-podcast","restore-state":!0,total:e.value,"show-provider-filter":!0},null,8,["update-available","title","total"]))}});export{x as default};
